.\" file MASS/rlm.d
.\" copyright (C) 1998,9 B. D. Ripley
.\"
.BG
.FN rlm
.TL
Robust Fitting of Linear Models
.DN
Fit a linear model by robust regression using an M estimator.
.CS
rlm(x, ...)
rlm.formula(formula, data, weights, ..., subset, na.action = na.fail,
            method = c("M", "MM", "model.frame"),
            wt.method = c("case", "inv.var"),
            model = TRUE, x.ret = TRUE, y.ret = FALSE, contrasts = NULL)
rlm.default(x, y, weights, ..., w = rep(1, nrow(x)),
            init, psi = psi.huber, scale.est, k2 = 1.345, 
            method = c("M", "MM"), wt.method = c("case", "inv.var"),
            maxit = 20, acc = 1e-4, test.vec = "resid")
.RA
.AG formula
a formula of the form `y ~ x1 + x2 + ...'.
.AG data
data frame from which variables specified in `formula' are
preferentially to be taken.
.AG weights
prior weights for each case.
.AG subset
An index vector specifying the cases to be used in
fitting.
.AG na.action
A function to specify the action to be taken if `NA's are found. The
default action is for the procedure to fail. An alternative is
`na.omit', which leads to omission of cases with missing values on any
required variable.
.AG x
a matrix or data frame containing the explanatory variables.
.AG y
the response: a vector of length the number of rows of `x'.
.AG method
currently either M-estimation or find the model frame. MM estimation
is M-estimation with Tukey's biweight initialized by a specific
S-estimator. See the details section.
.AG wt.method
are the weights case weights (giving the relative importance of case,
so a weight of 2 means there are two of these) or the inverse of the
variances, so a weight of two means this error is twice as variable?
.AG model
should the model frame be returned in the object?
.AG x.ret
should the model matrix be returned in the object?
.AG y.ret
should the response be returned in the object?
.AG contrasts
optional contrast specifications: se `lm'.
.AG w
(optional) initial down-weighting for each case.
.AG init
(optional) initial values for the coefficients OR a method to find
initial values OR the result of a fit with a `coef' component. Known
methods are `"ls"' (the default) for an initial least-squares fit
using weights `w*weights', and `"lqs"' for an unweighted least-trimmed
squares fit with 200 samples.
.AG psi
the psi function is specified by this argument. It must give
(possibly by name) a function `g(x, ..., deriv)' that for `deriv=0'
returns psi(x)/x and for `deriv=1' returns psi'(x). Tuning constants
will be passed in via `...'.
.AG scale.est
method of scale estimation: re-scaled MAD of the residuals or Huber's
proposal 2.
.AG k2
tuning constant used for Huber proposal 2 scale estimation.
.AG maxit
the limit on the number of IWLS iterations.
.AG acc
the accuracy for the stopping criterion.
.AG test.vec
the stopping criterion is based on changes in this vector.
.AG ...
additional arguments to be passed to `rlm.default' or to the `psi'
function.
.RT
An object of class `"rlm"' inheriting from `"lm"'.
The additional components not in an `lm' object are
.RC s
the robust scale estimate used
.RC w
the weights used in the IWLS process
.RC psi
the psi function with parameters substituted
.RC conv
the convergence criteria at each iteration
.RC converged
did the IWLS converge?
.DT
  Fitting is done by iterated re-weighted least squares (IWLS).
.PP
  Psi functions are supplied for the Huber, Hampel and Tukey bisquare
  proposals as `psi.huber', `psi.hampel' and
  `psi.bisquare'. Huber's corresponds to a convex optimization
  problem and gives a unique solution (up to collinearity). The other
  two will have multiple local minima, and a good starting point is
  desirable.
.PP
  Selecting `method = "MM"' selects a specific set of options which
  ensures that the estimator has a high breakdown point. The initial set
  of coefficients and the final scale are selected by an S-estimator
  with `k0 = 1.548'; this gives (for n >> p) breakdown point 0.5.
  The final estimator is an M-estimator with Tukey's biweight and fixed
  scale that will inherit this breakdown point provided `c > k0';
  this is true for the default value of `c' that corresponds to
  95% relative efficiency at the normal. 
.SH REFERENCES
P. J. Huber (1981) 
.ul
Robust Statistics. 
Wiley.
.PP 
F. R. Hampel, E. M. Ronchetti, P. J. Rousseeuw and W. A. Stahel (1986)
.ul
Robust Statistics: The Approach based on Influence Functions. 
Wiley.
.PP 
A. Marazzi (1993)
.ul
Algorithms, Routines and S Functions for Robust Statistics. 
Wadsworth & Brooks/Cole.
.SA
`lm', `lqs', `lmRobMM'.
.EX
stackloss <- data.frame(stack.x, stack.loss)
summary(rlm(stack.loss ~ ., stackloss))
rlm(stack.loss ~ ., stackloss, psi=psi.hampel, init="lts") 
rlm(stack.loss ~ ., stackloss, psi=psi.bisquare)
.KW models
.KW robust
.WR
