diagnostics <- function(x, ...) UseMethod("diagnostics")

VRarima <- function(x, order, seasonal, include.mean = T, ...)
{
    if(missing(order) || is.list(order))
        stop("order must be specified and not be a list")
    xn <- deparse(substitute(x))
    Call <- match.call()
    d <- order[2]
    order <- list(order = order)
    if(!missing(seasonal)) {
        sd <- seasonal$order[2]
        order <- list(order, seasonal)
    } else {
        sd <- 0
    }
    if(d == 0 && sd == 0 && include.mean) {
        xm <- mean(x)
        x <- x - xm
    } else xm <- 0
    res <- arima.mle(x, model = order, ...)
    res$mean <- xm
    res$series <- xn
    res$call <- Call
    class(res) <- "VRarima"
    res
}

print.VRarima <-
    function (x, digits = max(3, options("digits")$digits - 3), se = TRUE,
              ...)
{
    findCoefs <- function(model, st="")
    {
        res <- if(length(model$ma)) c(model$ar, -model$ma) else model$ar
        nar <- if(is.null(model$ar)) character(0) else paste(st, "ar", seq(along = model$ar), sep = "")
        nma <- if(is.null(model$ma)) character(0) else paste(st, "ma", seq(along = model$ma), sep = "")
        structure(res, names = c(nar, nma))
    }
#    cat("\nCall:\n", deparse(x$call), "\n\n", sep = "")
    cat("Coefficients:\n")
    if(!is.null(x$model$order)) # one model
        coef <- round(findCoefs(x$model), digits = digits)
    else {# two or more models
        coef <- round(findCoefs(x$model[[1]]), digits = digits)
        coef <- c(coef, round(findCoefs(x$model[[2]], "s"), digits = digits))
    }
    if (se && nrow(x$var.coef)) {
        ses <- round(sqrt(diag(x$var.coef)), digits = digits)
        coef <- matrix(coef, 1, dimnames = list(NULL, names(coef)))
        coef <- rbind(coef, "s.e."=ses)
    }
    print.default(coef)
    cat("\nsigma^2 = ", format(x$sigma2, digits = digits),
        ":  log likelihood = ", format(round(-x$loglik/2, 2)), ",  aic = ",
        format(round(x$aic, 2)), "\n", sep = "")
    invisible(x)
}

diagnostics.VRarima <- function(x, ...) invisible(arima.diag(x, ...))

predict.VRarima <-
    function(object, n.ahead = 1, se.fit = T, ...)
{
    res <- arima.forecast(get(object$series), n = n.ahead, object$model)
    res$mean <- res$mean + object$mean
    names(res) <- c("pred", "se")
    if(se.fit) res else res$pred
}
